@@ -141,6 +141,20 @@ sub country_del {
 }
 
 
+#
+# $player->destroy;
+#
+# Break all circular references in $player, to prevent memory leaks.
+#
+#sub DESTROY { say "destroy: $_[0]"; }
+sub destroy {
+    my ($self) = @_;
+    $self->ai(undef);
+    $self->_cards([]);
+    $self->_countries([]);
+}
+
+
 #
 # my $greatness = $player->greatness;
 #
@@ -267,6 +281,11 @@ Add C<$country> to the set of countries owned by C<$player>.
 Delete C<$country> from the set of countries owned by C<$player>.
 
 
+=item * $player->destroy()
+
+Break all circular references in C<$player>, to prevent memory leaks.
+
+
 =item * my $greatness = $player->greatness()
 
 Return an integer reflecting the greatness of C<$player>. It will raise
